collet.actions.s3


complete-multipart-uploadclj

(complete-multipart-upload s3-client bucket key upload-id parts)

Completes the multipart upload process.

Completes the multipart upload process.
sourceraw docstring

five-gb-in-bytesclj

source

initiate-multipart-uploadclj

(initiate-multipart-upload s3-client bucket key)

Initiates the multipart upload process.

Initiates the multipart upload process.
sourceraw docstring

invoke!clj

(invoke! client operation params)

Calls AWS invoke and captures the error message string and full response.

  • client (required) aws service client
  • operation (required) a keyword such as :GetObject
  • params (required) aws api request options
Calls AWS invoke and captures the error message string and full response.
- `client` (required) aws service client
- `operation` (required) a keyword such as :GetObject
- `params` (required) aws api request options
sourceraw docstring

make-clientclj

(make-client api {:keys [aws-region aws-key aws-secret endpoint-override]})

Creates an AWS client for the S3 service.

Creates an AWS client for the S3 service.
sourceraw docstring

multipart-uploadclj

(multipart-upload s3-client bucket key is)

Uploads a file larger than 5GB to S3 using multipart upload. The file is split into parts of 50MB each. Options: :s3-client - the S3 client :bucket - the S3 bucket name :key - the S3 key name :is - the input stream of the file

Uploads a file larger than 5GB to S3 using multipart upload.
The file is split into parts of 50MB each.
Options:
:s3-client - the S3 client
:bucket - the S3 bucket name
:key    - the S3 key name
:is     - the input stream of the file
sourceraw docstring

s3-params-specclj

source

upload-fileclj

(upload-file {:keys [aws-creds bucket format file-name input cat? csv-header?]
              :or {cat? false}})

Uploads a file to S3. Options: :aws-creds - the AWS credentials (region, key, secret) :bucket - the S3 bucket name :format - the format of the file (makes sense only if you're writing data into :json or :csv) :file-name - the name of the file :input - the data to write or the actual file (input stream or file path) :csv-header? - if true, the CSV file will have a header row

Uploads a file to S3.
Options:
:aws-creds   - the AWS credentials (region, key, secret)
:bucket      - the S3 bucket name
:format      - the format of the file (makes sense only if you're writing data into :json or :csv)
:file-name   - the name of the file
:input       - the data to write or the actual file (input stream or file path)
:csv-header? - if true, the CSV file will have a header row
sourceraw docstring

upload-partclj

(upload-part s3-client bucket key upload-id part-number part-content)

Uploads a part of a file to S3.

Uploads a part of a file to S3.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries